// The MIT License (MIT)
//
// ModernAVPlayer
// Copyright (c) 2018 Raphael Ankierman <raphael.ankierman@radiofrance.com>
//
// TableViewController.swift
// Created by raphael ankierman on 12/10/2019.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

import UIKit

final class TableViewController: UITableViewController {

    private let dataSource = DemoScreen.allCases

    override func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: "screenCell", for: indexPath)
        cell.textLabel?.text = dataSource[indexPath.row].description
        return cell
    }

    override func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return dataSource.count
    }

    override func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
        guard let navVC = navigationController else { assertionFailure(); return }

        let screen = dataSource[indexPath.row]
        let sb = UIStoryboard(name: screen.id, bundle: Bundle.main)
        let vc = sb.instantiateViewController(withIdentifier: screen.id)
        setupSimpleAudioInputSource(vc: vc, screen: screen)
        navVC.pushViewController(vc, animated: true)
    }

    private func setupSimpleAudioInputSource(vc: UIViewController, screen: DemoScreen) {
        guard let vc = vc as? SimpleAudioVC else { return }

        switch screen {
        case .simpleAudioURL:
            vc.inputSource = .URL
        case .simpleAudioAVPlayerItem:
            vc.inputSource = .AVPlayerItem
        default:
            preconditionFailure()
        }
    }
}
